import frontmatter

from cbr_website_beta.cbr__fastapi__markdown.markdown.md__extensions.Extension__Mermaid         import Extension__Mermaid
from cbr_website_beta.cbr__fastapi__markdown.markdown.md__extensions.Extension__Render_Template import Extension__Render_Template
from cbr_website_beta.cbr__fastapi__markdown.markdown.md__extensions.Extension__Video           import Extension__Video

from markdown                                           import Markdown
from osbot_utils.base_classes.Type_Safe                 import Type_Safe
from osbot_utils.decorators.methods.cache_on_self       import cache_on_self


class Markdown_Parser(Type_Safe):

    @cache_on_self
    def markdown(self):
        return Markdown(extensions=self.extensions())

    def extensions(self):
        return [Extension__Mermaid          (),
                Extension__Render_Template  (),
                Extension__Video            ()]

    def markdown_to_html(self, markdown_text):
        return self.markdown().convert(markdown_text)

    def content_to_html(self, content):
        _, markdown = frontmatter.parse(content)
        return  self.markdown_to_html(markdown)

markdown_parser = Markdown_Parser()


from pydantic import BaseModel

from cbr_website_beta.cbr__fastapi__markdown.markdown.Markdown_Parser import Markdown_Parser
from cbr_website_beta.config.CBR__Config__Data                         import cbr_config
from cbr_website_beta.config.CBR__Config__Data import cbr_config_active
from cbr_website_beta.config.CBR__Site_Info                     import CBR__Site_Info, cbr_site_info
from cbr_website_beta.utils.health_checks.CBR__Health_Checks    import CBR__Health_Checks, cbr_health_checks
from osbot_fast_api.api.Fast_API_Routes                         import Fast_API_Routes

ROUTE_PATH__SITE_INFO     = 'render'
EXPECTED_SITE_INFO_ROUTES = ['/extensions']

class Markdown_Text(BaseModel):
    text : str

class Routes__Markdown__Render(Fast_API_Routes):
    markdown_parser : Markdown_Parser
    tag             : str = ROUTE_PATH__SITE_INFO

    def extensions(self):
        return f'{self.markdown_parser.extensions()}'

    def markdown_to_html(self, markdown_text: Markdown_Text):
        return self.markdown_parser.markdown_to_html(markdown_text.text)

    def setup_routes(self):
        self.add_route_get (self.extensions)
        self.add_route_post(self.markdown_to_html)
